"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const template_1 = __importDefault(require("./template"));
const slide_1 = __importDefault(require("./slide"));
const file_1 = __importDefault(require("./helper/file"));
class Automizer {
    constructor(params) {
        this.templates = [];
        this.params = params;
        this.templateDir = (params === null || params === void 0 ? void 0 : params.templateDir) ? params.templateDir + '/' : '';
        this.outputDir = (params === null || params === void 0 ? void 0 : params.outputDir) ? params.outputDir + '/' : '';
    }
    importRootTemplate(location) {
        location = this.getLocation(location, 'template');
        let newTemplate = template_1.default.importRoot(location);
        this.rootTemplate = newTemplate;
        return this;
    }
    importTemplate(location, name) {
        location = this.getLocation(location, 'template');
        let newTemplate = template_1.default.import(location, name);
        this.templates.push(newTemplate);
        return this;
    }
    template(name) {
        return this.templates.find(template => template.name === name);
    }
    getLocation(location, type) {
        switch (type) {
            case 'template':
                return this.templateDir + location;
            case 'output':
                return this.outputDir + location;
            default:
                return location;
        }
    }
    /**
     * Find imported template by given name and return a certain slide available
     * @param {string} name - Name of template; must be imported by Automizer.importTemplate()
     * @param {number} slideNumber - Number of slide in template presentation
     * @return {Slide} Imported slide as an instance of Slide
     */
    addSlide(name, slideNumber) {
        let template = this.template(name);
        let newSlide = new slide_1.default({
            presentation: this,
            template: template,
            number: slideNumber
        });
        this.rootTemplate.slides.push(newSlide);
        return newSlide;
    }
    write(location) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.rootTemplate.countSlides();
            yield this.rootTemplate.countCharts();
            yield this.rootTemplate.countImages();
            let rootArchive = yield this.rootTemplate.archive;
            for (let i in this.rootTemplate.slides) {
                let slide = this.rootTemplate.slides[i];
                yield this.rootTemplate.appendSlide(slide);
            }
            let content = yield rootArchive.generateAsync({ type: "nodebuffer" });
            location = this.getLocation(location, 'output');
            return file_1.default.writeOutputFile(location, content);
        });
    }
}
exports.default = Automizer;
//# sourceMappingURL=automizer.js.map