"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chart_1 = __importDefault(require("./chart"));
const image_1 = __importDefault(require("./image"));
const file_1 = __importDefault(require("./helper/file"));
const xml_1 = __importDefault(require("./helper/xml"));
class Slide {
    constructor(params) {
        this.sourceTemplate = params.template;
        this.sourceNumber = params.number;
        this.modifications = [];
    }
    modify(callback) {
        this.modifications.push(callback);
    }
    setTarget(archive, targetTemplate) {
        this.targetTemplate = targetTemplate;
        this.targetArchive = archive;
        this.targetNumber = targetTemplate.slideCount;
        this.sourcePath = `ppt/slides/slide${this.sourceNumber}.xml`;
        this.relsPath = `ppt/slides/_rels/slide${this.sourceNumber}.xml.rels`;
        this.targetPath = `ppt/slides/slide${this.targetNumber}.xml`;
    }
    append() {
        return __awaiter(this, void 0, void 0, function* () {
            this.sourceArchive = yield this.sourceTemplate.archive;
            yield this.applyModifications();
            yield this.copySlideFiles();
            yield this.copyRelatedContent();
            yield this.addSlideToPresentation();
        });
    }
    applyModifications() {
        return __awaiter(this, void 0, void 0, function* () {
            for (let m in this.modifications) {
                let xml = yield xml_1.default.getXmlFromArchive(this.sourceArchive, this.sourcePath);
                this.modifications[m](xml);
                yield xml_1.default.writeXmlToArchive(this.sourceArchive, this.sourcePath, xml);
            }
        });
    }
    copySlideFiles() {
        return __awaiter(this, void 0, void 0, function* () {
            file_1.default.zipCopy(this.sourceArchive, `ppt/slides/slide${this.sourceNumber}.xml`, this.targetArchive, `ppt/slides/slide${this.targetNumber}.xml`);
            file_1.default.zipCopy(this.sourceArchive, `ppt/slides/_rels/slide${this.sourceNumber}.xml.rels`, this.targetArchive, `ppt/slides/_rels/slide${this.targetNumber}.xml.rels`);
        });
    }
    addSlideToPresentation() {
        return __awaiter(this, void 0, void 0, function* () {
            let relId = yield xml_1.default.getNextRelId(this.targetArchive, 'ppt/_rels/presentation.xml.rels');
            yield this.appendToSlideRel(this.targetArchive, relId, this.targetNumber),
                yield this.appendToSlideList(this.targetArchive, relId),
                yield this.appendToContentType(this.targetArchive, this.targetNumber);
        });
    }
    appendToSlideRel(rootArchive, relId, slideCount) {
        return xml_1.default.append({
            archive: rootArchive,
            file: `ppt/_rels/presentation.xml.rels`,
            parent: (xml) => xml.getElementsByTagName('Relationships')[0],
            tag: 'Relationship',
            attributes: {
                Id: relId,
                Type: `http://schemas.openxmlformats.org/officeDocument/2006/relationships/slide`,
                Target: `slides/slide${slideCount}.xml`
            }
        });
    }
    appendToSlideList(rootArchive, relId) {
        return xml_1.default.append({
            archive: rootArchive,
            file: `ppt/presentation.xml`,
            parent: (xml) => xml.getElementsByTagName('p:sldIdLst')[0],
            tag: 'p:sldId',
            attributes: {
                id: (xml) => xml_1.default.getMaxId(xml.getElementsByTagName('p:sldId'), 'id', true),
                'r:id': relId
            }
        });
    }
    appendToContentType(rootArchive, slideCount) {
        return xml_1.default.append(xml_1.default.createContentTypeChild(rootArchive, {
            PartName: `/ppt/slides/slide${slideCount}.xml`,
            ContentType: `application/vnd.openxmlformats-officedocument.presentationml.slide+xml`
        }));
    }
    copyRelatedContent() {
        return __awaiter(this, void 0, void 0, function* () {
            let charts = yield xml_1.default.getTargetsFromRelationships(this.sourceArchive, this.relsPath, '../charts/chart');
            for (let i in charts) {
                let newChart = new chart_1.default(charts[i], this.sourceArchive, this.targetNumber);
                this.targetTemplate.incrementChartCounter();
                yield this.targetTemplate.appendChart(newChart);
            }
            let images = yield xml_1.default.getTargetsByRelationshipType(this.sourceArchive, this.relsPath, "http://schemas.openxmlformats.org/officeDocument/2006/relationships/image");
            for (let i in images) {
                let newImage = new image_1.default(images[i], this.sourceArchive, this.targetNumber);
                this.targetTemplate.incrementImageCounter();
                yield this.targetTemplate.appendImage(newImage);
            }
        });
    }
}
exports.default = Slide;
//# sourceMappingURL=slide.js.map