/// <reference types="node" />
import { ISlide, ITemplate, IChart, PresTemplate, RootPresTemplate, IImage } from './types';
import JSZip from 'jszip';
declare class Template implements ITemplate {
    /**
     * Path to local file
     * @type string
     */
    location: string;
    /**
     * An alias name to identify template and simplify
     * @type string
     */
    name: string;
    /**
     * Node file buffer
     * @type Promise<Buffer>
     */
    file: Promise<Buffer>;
    /**
     * this.file will be passed to JSZip
     * @type Promise<JSZip>
     */
    archive: Promise<JSZip>;
    /**
     * Array containing all slides coming from Automizer.addSlide()
     * @type: ISlide[]
     */
    slides: ISlide[];
    /**
     * Contains actual number of slides in root template.
     * Has to be incremented before a new slide is appended.
     * @type: number
     */
    slideCount: number;
    chartCount: number;
    imageCount: number;
    constructor(location: string);
    static importRoot(location: string): RootPresTemplate;
    static import(location: string, name?: string): PresTemplate;
    appendSlide(slide: ISlide): Promise<void>;
    countSlides(): Promise<number>;
    incrementSlideCounter(): number;
    appendChart(shape: IChart): Promise<void>;
    countCharts(): Promise<number>;
    incrementChartCounter(): number;
    appendImage(shape: IImage): Promise<void>;
    countImages(): Promise<number>;
    incrementImageCounter(): number;
}
export default Template;
